// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: camera_lens.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_camera_5flens_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_camera_5flens_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_camera_5flens_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_camera_5flens_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
GZ_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_camera_5flens_2eproto;
namespace gazebo {
namespace msgs {
class CameraLens;
struct CameraLensDefaultTypeInternal;
GZ_MSGS_VISIBLE extern CameraLensDefaultTypeInternal _CameraLens_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::CameraLens* Arena::CreateMaybeMessage<::gazebo::msgs::CameraLens>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE CameraLens final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.CameraLens) */ {
 public:
  inline CameraLens() : CameraLens(nullptr) {}
  ~CameraLens() override;
  explicit constexpr CameraLens(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  CameraLens(const CameraLens& from);
  CameraLens(CameraLens&& from) noexcept
    : CameraLens() {
    *this = ::std::move(from);
  }

  inline CameraLens& operator=(const CameraLens& from) {
    CopyFrom(from);
    return *this;
  }
  inline CameraLens& operator=(CameraLens&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const CameraLens& default_instance() {
    return *internal_default_instance();
  }
  static inline const CameraLens* internal_default_instance() {
    return reinterpret_cast<const CameraLens*>(
               &_CameraLens_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(CameraLens& a, CameraLens& b) {
    a.Swap(&b);
  }
  inline void Swap(CameraLens* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CameraLens* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline CameraLens* New() const final {
    return new CameraLens();
  }

  CameraLens* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<CameraLens>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const CameraLens& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const CameraLens& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(CameraLens* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.CameraLens";
  }
  protected:
  explicit CameraLens(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kTypeFieldNumber = 1,
    kFunFieldNumber = 6,
    kC1FieldNumber = 2,
    kC2FieldNumber = 3,
    kC3FieldNumber = 4,
    kFFieldNumber = 5,
    kCutoffAngleFieldNumber = 8,
    kScaleToHfovFieldNumber = 7,
    kEnvTextureSizeFieldNumber = 10,
    kHfovFieldNumber = 9,
  };
  // required string type = 1;
  bool has_type() const;
  private:
  bool _internal_has_type() const;
  public:
  void clear_type();
  const std::string& type() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_type(ArgT0&& arg0, ArgT... args);
  std::string* mutable_type();
  PROTOBUF_MUST_USE_RESULT std::string* release_type();
  void set_allocated_type(std::string* type);
  private:
  const std::string& _internal_type() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_type(const std::string& value);
  std::string* _internal_mutable_type();
  public:

  // optional string fun = 6;
  bool has_fun() const;
  private:
  bool _internal_has_fun() const;
  public:
  void clear_fun();
  const std::string& fun() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_fun(ArgT0&& arg0, ArgT... args);
  std::string* mutable_fun();
  PROTOBUF_MUST_USE_RESULT std::string* release_fun();
  void set_allocated_fun(std::string* fun);
  private:
  const std::string& _internal_fun() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_fun(const std::string& value);
  std::string* _internal_mutable_fun();
  public:

  // optional double c1 = 2;
  bool has_c1() const;
  private:
  bool _internal_has_c1() const;
  public:
  void clear_c1();
  double c1() const;
  void set_c1(double value);
  private:
  double _internal_c1() const;
  void _internal_set_c1(double value);
  public:

  // optional double c2 = 3;
  bool has_c2() const;
  private:
  bool _internal_has_c2() const;
  public:
  void clear_c2();
  double c2() const;
  void set_c2(double value);
  private:
  double _internal_c2() const;
  void _internal_set_c2(double value);
  public:

  // optional double c3 = 4;
  bool has_c3() const;
  private:
  bool _internal_has_c3() const;
  public:
  void clear_c3();
  double c3() const;
  void set_c3(double value);
  private:
  double _internal_c3() const;
  void _internal_set_c3(double value);
  public:

  // optional double f = 5;
  bool has_f() const;
  private:
  bool _internal_has_f() const;
  public:
  void clear_f();
  double f() const;
  void set_f(double value);
  private:
  double _internal_f() const;
  void _internal_set_f(double value);
  public:

  // optional double cutoff_angle = 8;
  bool has_cutoff_angle() const;
  private:
  bool _internal_has_cutoff_angle() const;
  public:
  void clear_cutoff_angle();
  double cutoff_angle() const;
  void set_cutoff_angle(double value);
  private:
  double _internal_cutoff_angle() const;
  void _internal_set_cutoff_angle(double value);
  public:

  // optional bool scale_to_hfov = 7;
  bool has_scale_to_hfov() const;
  private:
  bool _internal_has_scale_to_hfov() const;
  public:
  void clear_scale_to_hfov();
  bool scale_to_hfov() const;
  void set_scale_to_hfov(bool value);
  private:
  bool _internal_scale_to_hfov() const;
  void _internal_set_scale_to_hfov(bool value);
  public:

  // optional int32 env_texture_size = 10;
  bool has_env_texture_size() const;
  private:
  bool _internal_has_env_texture_size() const;
  public:
  void clear_env_texture_size();
  ::PROTOBUF_NAMESPACE_ID::int32 env_texture_size() const;
  void set_env_texture_size(::PROTOBUF_NAMESPACE_ID::int32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::int32 _internal_env_texture_size() const;
  void _internal_set_env_texture_size(::PROTOBUF_NAMESPACE_ID::int32 value);
  public:

  // optional double hfov = 9;
  bool has_hfov() const;
  private:
  bool _internal_has_hfov() const;
  public:
  void clear_hfov();
  double hfov() const;
  void set_hfov(double value);
  private:
  double _internal_hfov() const;
  void _internal_set_hfov(double value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.CameraLens)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr type_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr fun_;
  double c1_;
  double c2_;
  double c3_;
  double f_;
  double cutoff_angle_;
  bool scale_to_hfov_;
  ::PROTOBUF_NAMESPACE_ID::int32 env_texture_size_;
  double hfov_;
  friend struct ::TableStruct_camera_5flens_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// CameraLens

// required string type = 1;
inline bool CameraLens::_internal_has_type() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool CameraLens::has_type() const {
  return _internal_has_type();
}
inline void CameraLens::clear_type() {
  type_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000001u;
}
inline const std::string& CameraLens::type() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.type)
  return _internal_type();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void CameraLens::set_type(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000001u;
 type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.type)
}
inline std::string* CameraLens::mutable_type() {
  std::string* _s = _internal_mutable_type();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.CameraLens.type)
  return _s;
}
inline const std::string& CameraLens::_internal_type() const {
  return type_.Get();
}
inline void CameraLens::_internal_set_type(const std::string& value) {
  _has_bits_[0] |= 0x00000001u;
  type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* CameraLens::_internal_mutable_type() {
  _has_bits_[0] |= 0x00000001u;
  return type_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* CameraLens::release_type() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.CameraLens.type)
  if (!_internal_has_type()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000001u;
  return type_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void CameraLens::set_allocated_type(std::string* type) {
  if (type != nullptr) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  type_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), type,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.CameraLens.type)
}

// optional double c1 = 2;
inline bool CameraLens::_internal_has_c1() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool CameraLens::has_c1() const {
  return _internal_has_c1();
}
inline void CameraLens::clear_c1() {
  c1_ = 0;
  _has_bits_[0] &= ~0x00000004u;
}
inline double CameraLens::_internal_c1() const {
  return c1_;
}
inline double CameraLens::c1() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.c1)
  return _internal_c1();
}
inline void CameraLens::_internal_set_c1(double value) {
  _has_bits_[0] |= 0x00000004u;
  c1_ = value;
}
inline void CameraLens::set_c1(double value) {
  _internal_set_c1(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.c1)
}

// optional double c2 = 3;
inline bool CameraLens::_internal_has_c2() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool CameraLens::has_c2() const {
  return _internal_has_c2();
}
inline void CameraLens::clear_c2() {
  c2_ = 0;
  _has_bits_[0] &= ~0x00000008u;
}
inline double CameraLens::_internal_c2() const {
  return c2_;
}
inline double CameraLens::c2() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.c2)
  return _internal_c2();
}
inline void CameraLens::_internal_set_c2(double value) {
  _has_bits_[0] |= 0x00000008u;
  c2_ = value;
}
inline void CameraLens::set_c2(double value) {
  _internal_set_c2(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.c2)
}

// optional double c3 = 4;
inline bool CameraLens::_internal_has_c3() const {
  bool value = (_has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool CameraLens::has_c3() const {
  return _internal_has_c3();
}
inline void CameraLens::clear_c3() {
  c3_ = 0;
  _has_bits_[0] &= ~0x00000010u;
}
inline double CameraLens::_internal_c3() const {
  return c3_;
}
inline double CameraLens::c3() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.c3)
  return _internal_c3();
}
inline void CameraLens::_internal_set_c3(double value) {
  _has_bits_[0] |= 0x00000010u;
  c3_ = value;
}
inline void CameraLens::set_c3(double value) {
  _internal_set_c3(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.c3)
}

// optional double f = 5;
inline bool CameraLens::_internal_has_f() const {
  bool value = (_has_bits_[0] & 0x00000020u) != 0;
  return value;
}
inline bool CameraLens::has_f() const {
  return _internal_has_f();
}
inline void CameraLens::clear_f() {
  f_ = 0;
  _has_bits_[0] &= ~0x00000020u;
}
inline double CameraLens::_internal_f() const {
  return f_;
}
inline double CameraLens::f() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.f)
  return _internal_f();
}
inline void CameraLens::_internal_set_f(double value) {
  _has_bits_[0] |= 0x00000020u;
  f_ = value;
}
inline void CameraLens::set_f(double value) {
  _internal_set_f(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.f)
}

// optional string fun = 6;
inline bool CameraLens::_internal_has_fun() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool CameraLens::has_fun() const {
  return _internal_has_fun();
}
inline void CameraLens::clear_fun() {
  fun_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000002u;
}
inline const std::string& CameraLens::fun() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.fun)
  return _internal_fun();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void CameraLens::set_fun(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000002u;
 fun_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.fun)
}
inline std::string* CameraLens::mutable_fun() {
  std::string* _s = _internal_mutable_fun();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.CameraLens.fun)
  return _s;
}
inline const std::string& CameraLens::_internal_fun() const {
  return fun_.Get();
}
inline void CameraLens::_internal_set_fun(const std::string& value) {
  _has_bits_[0] |= 0x00000002u;
  fun_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* CameraLens::_internal_mutable_fun() {
  _has_bits_[0] |= 0x00000002u;
  return fun_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* CameraLens::release_fun() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.CameraLens.fun)
  if (!_internal_has_fun()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000002u;
  return fun_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void CameraLens::set_allocated_fun(std::string* fun) {
  if (fun != nullptr) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  fun_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), fun,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.CameraLens.fun)
}

// optional bool scale_to_hfov = 7;
inline bool CameraLens::_internal_has_scale_to_hfov() const {
  bool value = (_has_bits_[0] & 0x00000080u) != 0;
  return value;
}
inline bool CameraLens::has_scale_to_hfov() const {
  return _internal_has_scale_to_hfov();
}
inline void CameraLens::clear_scale_to_hfov() {
  scale_to_hfov_ = false;
  _has_bits_[0] &= ~0x00000080u;
}
inline bool CameraLens::_internal_scale_to_hfov() const {
  return scale_to_hfov_;
}
inline bool CameraLens::scale_to_hfov() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.scale_to_hfov)
  return _internal_scale_to_hfov();
}
inline void CameraLens::_internal_set_scale_to_hfov(bool value) {
  _has_bits_[0] |= 0x00000080u;
  scale_to_hfov_ = value;
}
inline void CameraLens::set_scale_to_hfov(bool value) {
  _internal_set_scale_to_hfov(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.scale_to_hfov)
}

// optional double cutoff_angle = 8;
inline bool CameraLens::_internal_has_cutoff_angle() const {
  bool value = (_has_bits_[0] & 0x00000040u) != 0;
  return value;
}
inline bool CameraLens::has_cutoff_angle() const {
  return _internal_has_cutoff_angle();
}
inline void CameraLens::clear_cutoff_angle() {
  cutoff_angle_ = 0;
  _has_bits_[0] &= ~0x00000040u;
}
inline double CameraLens::_internal_cutoff_angle() const {
  return cutoff_angle_;
}
inline double CameraLens::cutoff_angle() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.cutoff_angle)
  return _internal_cutoff_angle();
}
inline void CameraLens::_internal_set_cutoff_angle(double value) {
  _has_bits_[0] |= 0x00000040u;
  cutoff_angle_ = value;
}
inline void CameraLens::set_cutoff_angle(double value) {
  _internal_set_cutoff_angle(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.cutoff_angle)
}

// optional double hfov = 9;
inline bool CameraLens::_internal_has_hfov() const {
  bool value = (_has_bits_[0] & 0x00000200u) != 0;
  return value;
}
inline bool CameraLens::has_hfov() const {
  return _internal_has_hfov();
}
inline void CameraLens::clear_hfov() {
  hfov_ = 0;
  _has_bits_[0] &= ~0x00000200u;
}
inline double CameraLens::_internal_hfov() const {
  return hfov_;
}
inline double CameraLens::hfov() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.hfov)
  return _internal_hfov();
}
inline void CameraLens::_internal_set_hfov(double value) {
  _has_bits_[0] |= 0x00000200u;
  hfov_ = value;
}
inline void CameraLens::set_hfov(double value) {
  _internal_set_hfov(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.hfov)
}

// optional int32 env_texture_size = 10;
inline bool CameraLens::_internal_has_env_texture_size() const {
  bool value = (_has_bits_[0] & 0x00000100u) != 0;
  return value;
}
inline bool CameraLens::has_env_texture_size() const {
  return _internal_has_env_texture_size();
}
inline void CameraLens::clear_env_texture_size() {
  env_texture_size_ = 0;
  _has_bits_[0] &= ~0x00000100u;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 CameraLens::_internal_env_texture_size() const {
  return env_texture_size_;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 CameraLens::env_texture_size() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.CameraLens.env_texture_size)
  return _internal_env_texture_size();
}
inline void CameraLens::_internal_set_env_texture_size(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _has_bits_[0] |= 0x00000100u;
  env_texture_size_ = value;
}
inline void CameraLens::set_env_texture_size(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _internal_set_env_texture_size(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.CameraLens.env_texture_size)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::CameraLens> CameraLensPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::CameraLens const> ConstCameraLensPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_camera_5flens_2eproto
