// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: server_control.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_server_5fcontrol_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_server_5fcontrol_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_server_5fcontrol_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_server_5fcontrol_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
GZ_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_server_5fcontrol_2eproto;
namespace gazebo {
namespace msgs {
class ServerControl;
struct ServerControlDefaultTypeInternal;
GZ_MSGS_VISIBLE extern ServerControlDefaultTypeInternal _ServerControl_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::ServerControl* Arena::CreateMaybeMessage<::gazebo::msgs::ServerControl>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE ServerControl final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.ServerControl) */ {
 public:
  inline ServerControl() : ServerControl(nullptr) {}
  ~ServerControl() override;
  explicit constexpr ServerControl(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  ServerControl(const ServerControl& from);
  ServerControl(ServerControl&& from) noexcept
    : ServerControl() {
    *this = ::std::move(from);
  }

  inline ServerControl& operator=(const ServerControl& from) {
    CopyFrom(from);
    return *this;
  }
  inline ServerControl& operator=(ServerControl&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const ServerControl& default_instance() {
    return *internal_default_instance();
  }
  static inline const ServerControl* internal_default_instance() {
    return reinterpret_cast<const ServerControl*>(
               &_ServerControl_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(ServerControl& a, ServerControl& b) {
    a.Swap(&b);
  }
  inline void Swap(ServerControl* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ServerControl* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline ServerControl* New() const final {
    return new ServerControl();
  }

  ServerControl* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<ServerControl>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const ServerControl& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const ServerControl& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(ServerControl* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.ServerControl";
  }
  protected:
  explicit ServerControl(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kSaveWorldNameFieldNumber = 1,
    kSaveFilenameFieldNumber = 2,
    kOpenFilenameFieldNumber = 3,
    kNewWorldFieldNumber = 4,
    kStopFieldNumber = 5,
    kCloneFieldNumber = 6,
    kNewPortFieldNumber = 7,
  };
  // optional string save_world_name = 1;
  bool has_save_world_name() const;
  private:
  bool _internal_has_save_world_name() const;
  public:
  void clear_save_world_name();
  const std::string& save_world_name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_save_world_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_save_world_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_save_world_name();
  void set_allocated_save_world_name(std::string* save_world_name);
  private:
  const std::string& _internal_save_world_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_save_world_name(const std::string& value);
  std::string* _internal_mutable_save_world_name();
  public:

  // optional string save_filename = 2;
  bool has_save_filename() const;
  private:
  bool _internal_has_save_filename() const;
  public:
  void clear_save_filename();
  const std::string& save_filename() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_save_filename(ArgT0&& arg0, ArgT... args);
  std::string* mutable_save_filename();
  PROTOBUF_MUST_USE_RESULT std::string* release_save_filename();
  void set_allocated_save_filename(std::string* save_filename);
  private:
  const std::string& _internal_save_filename() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_save_filename(const std::string& value);
  std::string* _internal_mutable_save_filename();
  public:

  // optional string open_filename = 3;
  bool has_open_filename() const;
  private:
  bool _internal_has_open_filename() const;
  public:
  void clear_open_filename();
  const std::string& open_filename() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_open_filename(ArgT0&& arg0, ArgT... args);
  std::string* mutable_open_filename();
  PROTOBUF_MUST_USE_RESULT std::string* release_open_filename();
  void set_allocated_open_filename(std::string* open_filename);
  private:
  const std::string& _internal_open_filename() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_open_filename(const std::string& value);
  std::string* _internal_mutable_open_filename();
  public:

  // optional bool new_world = 4;
  bool has_new_world() const;
  private:
  bool _internal_has_new_world() const;
  public:
  void clear_new_world();
  bool new_world() const;
  void set_new_world(bool value);
  private:
  bool _internal_new_world() const;
  void _internal_set_new_world(bool value);
  public:

  // optional bool stop = 5;
  bool has_stop() const;
  private:
  bool _internal_has_stop() const;
  public:
  void clear_stop();
  bool stop() const;
  void set_stop(bool value);
  private:
  bool _internal_stop() const;
  void _internal_set_stop(bool value);
  public:

  // optional bool clone = 6;
  bool has_clone() const;
  private:
  bool _internal_has_clone() const;
  public:
  void clear_clone();
  bool clone() const;
  void set_clone(bool value);
  private:
  bool _internal_clone() const;
  void _internal_set_clone(bool value);
  public:

  // optional uint32 new_port = 7;
  bool has_new_port() const;
  private:
  bool _internal_has_new_port() const;
  public:
  void clear_new_port();
  ::PROTOBUF_NAMESPACE_ID::uint32 new_port() const;
  void set_new_port(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_new_port() const;
  void _internal_set_new_port(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.ServerControl)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr save_world_name_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr save_filename_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr open_filename_;
  bool new_world_;
  bool stop_;
  bool clone_;
  ::PROTOBUF_NAMESPACE_ID::uint32 new_port_;
  friend struct ::TableStruct_server_5fcontrol_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// ServerControl

// optional string save_world_name = 1;
inline bool ServerControl::_internal_has_save_world_name() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool ServerControl::has_save_world_name() const {
  return _internal_has_save_world_name();
}
inline void ServerControl::clear_save_world_name() {
  save_world_name_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000001u;
}
inline const std::string& ServerControl::save_world_name() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ServerControl.save_world_name)
  return _internal_save_world_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void ServerControl::set_save_world_name(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000001u;
 save_world_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.ServerControl.save_world_name)
}
inline std::string* ServerControl::mutable_save_world_name() {
  std::string* _s = _internal_mutable_save_world_name();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.ServerControl.save_world_name)
  return _s;
}
inline const std::string& ServerControl::_internal_save_world_name() const {
  return save_world_name_.Get();
}
inline void ServerControl::_internal_set_save_world_name(const std::string& value) {
  _has_bits_[0] |= 0x00000001u;
  save_world_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* ServerControl::_internal_mutable_save_world_name() {
  _has_bits_[0] |= 0x00000001u;
  return save_world_name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* ServerControl::release_save_world_name() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.ServerControl.save_world_name)
  if (!_internal_has_save_world_name()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000001u;
  return save_world_name_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void ServerControl::set_allocated_save_world_name(std::string* save_world_name) {
  if (save_world_name != nullptr) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  save_world_name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), save_world_name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.ServerControl.save_world_name)
}

// optional string save_filename = 2;
inline bool ServerControl::_internal_has_save_filename() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool ServerControl::has_save_filename() const {
  return _internal_has_save_filename();
}
inline void ServerControl::clear_save_filename() {
  save_filename_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000002u;
}
inline const std::string& ServerControl::save_filename() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ServerControl.save_filename)
  return _internal_save_filename();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void ServerControl::set_save_filename(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000002u;
 save_filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.ServerControl.save_filename)
}
inline std::string* ServerControl::mutable_save_filename() {
  std::string* _s = _internal_mutable_save_filename();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.ServerControl.save_filename)
  return _s;
}
inline const std::string& ServerControl::_internal_save_filename() const {
  return save_filename_.Get();
}
inline void ServerControl::_internal_set_save_filename(const std::string& value) {
  _has_bits_[0] |= 0x00000002u;
  save_filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* ServerControl::_internal_mutable_save_filename() {
  _has_bits_[0] |= 0x00000002u;
  return save_filename_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* ServerControl::release_save_filename() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.ServerControl.save_filename)
  if (!_internal_has_save_filename()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000002u;
  return save_filename_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void ServerControl::set_allocated_save_filename(std::string* save_filename) {
  if (save_filename != nullptr) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  save_filename_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), save_filename,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.ServerControl.save_filename)
}

// optional string open_filename = 3;
inline bool ServerControl::_internal_has_open_filename() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool ServerControl::has_open_filename() const {
  return _internal_has_open_filename();
}
inline void ServerControl::clear_open_filename() {
  open_filename_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000004u;
}
inline const std::string& ServerControl::open_filename() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ServerControl.open_filename)
  return _internal_open_filename();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void ServerControl::set_open_filename(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000004u;
 open_filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.ServerControl.open_filename)
}
inline std::string* ServerControl::mutable_open_filename() {
  std::string* _s = _internal_mutable_open_filename();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.ServerControl.open_filename)
  return _s;
}
inline const std::string& ServerControl::_internal_open_filename() const {
  return open_filename_.Get();
}
inline void ServerControl::_internal_set_open_filename(const std::string& value) {
  _has_bits_[0] |= 0x00000004u;
  open_filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* ServerControl::_internal_mutable_open_filename() {
  _has_bits_[0] |= 0x00000004u;
  return open_filename_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* ServerControl::release_open_filename() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.ServerControl.open_filename)
  if (!_internal_has_open_filename()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000004u;
  return open_filename_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void ServerControl::set_allocated_open_filename(std::string* open_filename) {
  if (open_filename != nullptr) {
    _has_bits_[0] |= 0x00000004u;
  } else {
    _has_bits_[0] &= ~0x00000004u;
  }
  open_filename_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), open_filename,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.ServerControl.open_filename)
}

// optional bool new_world = 4;
inline bool ServerControl::_internal_has_new_world() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool ServerControl::has_new_world() const {
  return _internal_has_new_world();
}
inline void ServerControl::clear_new_world() {
  new_world_ = false;
  _has_bits_[0] &= ~0x00000008u;
}
inline bool ServerControl::_internal_new_world() const {
  return new_world_;
}
inline bool ServerControl::new_world() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ServerControl.new_world)
  return _internal_new_world();
}
inline void ServerControl::_internal_set_new_world(bool value) {
  _has_bits_[0] |= 0x00000008u;
  new_world_ = value;
}
inline void ServerControl::set_new_world(bool value) {
  _internal_set_new_world(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.ServerControl.new_world)
}

// optional bool stop = 5;
inline bool ServerControl::_internal_has_stop() const {
  bool value = (_has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool ServerControl::has_stop() const {
  return _internal_has_stop();
}
inline void ServerControl::clear_stop() {
  stop_ = false;
  _has_bits_[0] &= ~0x00000010u;
}
inline bool ServerControl::_internal_stop() const {
  return stop_;
}
inline bool ServerControl::stop() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ServerControl.stop)
  return _internal_stop();
}
inline void ServerControl::_internal_set_stop(bool value) {
  _has_bits_[0] |= 0x00000010u;
  stop_ = value;
}
inline void ServerControl::set_stop(bool value) {
  _internal_set_stop(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.ServerControl.stop)
}

// optional bool clone = 6;
inline bool ServerControl::_internal_has_clone() const {
  bool value = (_has_bits_[0] & 0x00000020u) != 0;
  return value;
}
inline bool ServerControl::has_clone() const {
  return _internal_has_clone();
}
inline void ServerControl::clear_clone() {
  clone_ = false;
  _has_bits_[0] &= ~0x00000020u;
}
inline bool ServerControl::_internal_clone() const {
  return clone_;
}
inline bool ServerControl::clone() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ServerControl.clone)
  return _internal_clone();
}
inline void ServerControl::_internal_set_clone(bool value) {
  _has_bits_[0] |= 0x00000020u;
  clone_ = value;
}
inline void ServerControl::set_clone(bool value) {
  _internal_set_clone(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.ServerControl.clone)
}

// optional uint32 new_port = 7;
inline bool ServerControl::_internal_has_new_port() const {
  bool value = (_has_bits_[0] & 0x00000040u) != 0;
  return value;
}
inline bool ServerControl::has_new_port() const {
  return _internal_has_new_port();
}
inline void ServerControl::clear_new_port() {
  new_port_ = 0u;
  _has_bits_[0] &= ~0x00000040u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 ServerControl::_internal_new_port() const {
  return new_port_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 ServerControl::new_port() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ServerControl.new_port)
  return _internal_new_port();
}
inline void ServerControl::_internal_set_new_port(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _has_bits_[0] |= 0x00000040u;
  new_port_ = value;
}
inline void ServerControl::set_new_port(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_new_port(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.ServerControl.new_port)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::ServerControl> ServerControlPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::ServerControl const> ConstServerControlPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_server_5fcontrol_2eproto
