syntax = "proto2";
package gazebo.msgs;

/// \ingroup gazebo_msgs
/// \interface Model_V 
/// \brief Information about all entities in a world


import "model.proto";

message Model_V
{
  repeated Model models  = 2;
}

