syntax = "proto2";
package gazebo.msgs;

/// \ingroup gazebo_msgs
/// \interface PoseAnimation 
/// \brief Message for a model pose animation


import "pose.proto";
import "time.proto";

message PoseAnimation
{
  required string model_name      = 1;
  optional uint32 model_id        = 2;
  repeated Pose pose              = 3;
  repeated Time time              = 4;
}
