syntax = "proto2";
package gazebo.msgs;

/// \ingroup gazebo_msgs
/// \interface WorldControl
/// \brief A message that allows for control of world functions

import "world_reset.proto";

message WorldControl
{
  optional bool pause           = 1;
  optional bool step            = 2;
  optional uint32 multi_step    = 3;
  optional WorldReset reset     = 4;
  optional uint32 seed          = 5;
}
