// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: gps_sensor.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_gps_5fsensor_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_gps_5fsensor_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "sensor_noise.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_gps_5fsensor_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_gps_5fsensor_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[2]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
GZ_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_gps_5fsensor_2eproto;
namespace gazebo {
namespace msgs {
class GPSSensor;
struct GPSSensorDefaultTypeInternal;
GZ_MSGS_VISIBLE extern GPSSensorDefaultTypeInternal _GPSSensor_default_instance_;
class GPSSensor_Sensing;
struct GPSSensor_SensingDefaultTypeInternal;
GZ_MSGS_VISIBLE extern GPSSensor_SensingDefaultTypeInternal _GPSSensor_Sensing_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::GPSSensor* Arena::CreateMaybeMessage<::gazebo::msgs::GPSSensor>(Arena*);
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::GPSSensor_Sensing* Arena::CreateMaybeMessage<::gazebo::msgs::GPSSensor_Sensing>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE GPSSensor_Sensing final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.GPSSensor.Sensing) */ {
 public:
  inline GPSSensor_Sensing() : GPSSensor_Sensing(nullptr) {}
  ~GPSSensor_Sensing() override;
  explicit constexpr GPSSensor_Sensing(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  GPSSensor_Sensing(const GPSSensor_Sensing& from);
  GPSSensor_Sensing(GPSSensor_Sensing&& from) noexcept
    : GPSSensor_Sensing() {
    *this = ::std::move(from);
  }

  inline GPSSensor_Sensing& operator=(const GPSSensor_Sensing& from) {
    CopyFrom(from);
    return *this;
  }
  inline GPSSensor_Sensing& operator=(GPSSensor_Sensing&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const GPSSensor_Sensing& default_instance() {
    return *internal_default_instance();
  }
  static inline const GPSSensor_Sensing* internal_default_instance() {
    return reinterpret_cast<const GPSSensor_Sensing*>(
               &_GPSSensor_Sensing_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(GPSSensor_Sensing& a, GPSSensor_Sensing& b) {
    a.Swap(&b);
  }
  inline void Swap(GPSSensor_Sensing* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(GPSSensor_Sensing* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline GPSSensor_Sensing* New() const final {
    return new GPSSensor_Sensing();
  }

  GPSSensor_Sensing* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<GPSSensor_Sensing>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const GPSSensor_Sensing& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const GPSSensor_Sensing& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(GPSSensor_Sensing* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.GPSSensor.Sensing";
  }
  protected:
  explicit GPSSensor_Sensing(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kHorizontalNoiseFieldNumber = 1,
    kVerticalNoiseFieldNumber = 2,
  };
  // optional .gazebo.msgs.SensorNoise horizontal_noise = 1;
  bool has_horizontal_noise() const;
  private:
  bool _internal_has_horizontal_noise() const;
  public:
  void clear_horizontal_noise();
  const ::gazebo::msgs::SensorNoise& horizontal_noise() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::SensorNoise* release_horizontal_noise();
  ::gazebo::msgs::SensorNoise* mutable_horizontal_noise();
  void set_allocated_horizontal_noise(::gazebo::msgs::SensorNoise* horizontal_noise);
  private:
  const ::gazebo::msgs::SensorNoise& _internal_horizontal_noise() const;
  ::gazebo::msgs::SensorNoise* _internal_mutable_horizontal_noise();
  public:
  void unsafe_arena_set_allocated_horizontal_noise(
      ::gazebo::msgs::SensorNoise* horizontal_noise);
  ::gazebo::msgs::SensorNoise* unsafe_arena_release_horizontal_noise();

  // optional .gazebo.msgs.SensorNoise vertical_noise = 2;
  bool has_vertical_noise() const;
  private:
  bool _internal_has_vertical_noise() const;
  public:
  void clear_vertical_noise();
  const ::gazebo::msgs::SensorNoise& vertical_noise() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::SensorNoise* release_vertical_noise();
  ::gazebo::msgs::SensorNoise* mutable_vertical_noise();
  void set_allocated_vertical_noise(::gazebo::msgs::SensorNoise* vertical_noise);
  private:
  const ::gazebo::msgs::SensorNoise& _internal_vertical_noise() const;
  ::gazebo::msgs::SensorNoise* _internal_mutable_vertical_noise();
  public:
  void unsafe_arena_set_allocated_vertical_noise(
      ::gazebo::msgs::SensorNoise* vertical_noise);
  ::gazebo::msgs::SensorNoise* unsafe_arena_release_vertical_noise();

  // @@protoc_insertion_point(class_scope:gazebo.msgs.GPSSensor.Sensing)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::gazebo::msgs::SensorNoise* horizontal_noise_;
  ::gazebo::msgs::SensorNoise* vertical_noise_;
  friend struct ::TableStruct_gps_5fsensor_2eproto;
};
// -------------------------------------------------------------------

class GZ_MSGS_VISIBLE GPSSensor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.GPSSensor) */ {
 public:
  inline GPSSensor() : GPSSensor(nullptr) {}
  ~GPSSensor() override;
  explicit constexpr GPSSensor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  GPSSensor(const GPSSensor& from);
  GPSSensor(GPSSensor&& from) noexcept
    : GPSSensor() {
    *this = ::std::move(from);
  }

  inline GPSSensor& operator=(const GPSSensor& from) {
    CopyFrom(from);
    return *this;
  }
  inline GPSSensor& operator=(GPSSensor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const GPSSensor& default_instance() {
    return *internal_default_instance();
  }
  static inline const GPSSensor* internal_default_instance() {
    return reinterpret_cast<const GPSSensor*>(
               &_GPSSensor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(GPSSensor& a, GPSSensor& b) {
    a.Swap(&b);
  }
  inline void Swap(GPSSensor* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(GPSSensor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline GPSSensor* New() const final {
    return new GPSSensor();
  }

  GPSSensor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<GPSSensor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const GPSSensor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const GPSSensor& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(GPSSensor* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.GPSSensor";
  }
  protected:
  explicit GPSSensor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef GPSSensor_Sensing Sensing;

  // accessors -------------------------------------------------------

  enum : int {
    kPositionFieldNumber = 1,
    kVelocityFieldNumber = 2,
  };
  // optional .gazebo.msgs.GPSSensor.Sensing position = 1;
  bool has_position() const;
  private:
  bool _internal_has_position() const;
  public:
  void clear_position();
  const ::gazebo::msgs::GPSSensor_Sensing& position() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::GPSSensor_Sensing* release_position();
  ::gazebo::msgs::GPSSensor_Sensing* mutable_position();
  void set_allocated_position(::gazebo::msgs::GPSSensor_Sensing* position);
  private:
  const ::gazebo::msgs::GPSSensor_Sensing& _internal_position() const;
  ::gazebo::msgs::GPSSensor_Sensing* _internal_mutable_position();
  public:
  void unsafe_arena_set_allocated_position(
      ::gazebo::msgs::GPSSensor_Sensing* position);
  ::gazebo::msgs::GPSSensor_Sensing* unsafe_arena_release_position();

  // optional .gazebo.msgs.GPSSensor.Sensing velocity = 2;
  bool has_velocity() const;
  private:
  bool _internal_has_velocity() const;
  public:
  void clear_velocity();
  const ::gazebo::msgs::GPSSensor_Sensing& velocity() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::GPSSensor_Sensing* release_velocity();
  ::gazebo::msgs::GPSSensor_Sensing* mutable_velocity();
  void set_allocated_velocity(::gazebo::msgs::GPSSensor_Sensing* velocity);
  private:
  const ::gazebo::msgs::GPSSensor_Sensing& _internal_velocity() const;
  ::gazebo::msgs::GPSSensor_Sensing* _internal_mutable_velocity();
  public:
  void unsafe_arena_set_allocated_velocity(
      ::gazebo::msgs::GPSSensor_Sensing* velocity);
  ::gazebo::msgs::GPSSensor_Sensing* unsafe_arena_release_velocity();

  // @@protoc_insertion_point(class_scope:gazebo.msgs.GPSSensor)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::gazebo::msgs::GPSSensor_Sensing* position_;
  ::gazebo::msgs::GPSSensor_Sensing* velocity_;
  friend struct ::TableStruct_gps_5fsensor_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// GPSSensor_Sensing

// optional .gazebo.msgs.SensorNoise horizontal_noise = 1;
inline bool GPSSensor_Sensing::_internal_has_horizontal_noise() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || horizontal_noise_ != nullptr);
  return value;
}
inline bool GPSSensor_Sensing::has_horizontal_noise() const {
  return _internal_has_horizontal_noise();
}
inline const ::gazebo::msgs::SensorNoise& GPSSensor_Sensing::_internal_horizontal_noise() const {
  const ::gazebo::msgs::SensorNoise* p = horizontal_noise_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::SensorNoise&>(
      ::gazebo::msgs::_SensorNoise_default_instance_);
}
inline const ::gazebo::msgs::SensorNoise& GPSSensor_Sensing::horizontal_noise() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPSSensor.Sensing.horizontal_noise)
  return _internal_horizontal_noise();
}
inline void GPSSensor_Sensing::unsafe_arena_set_allocated_horizontal_noise(
    ::gazebo::msgs::SensorNoise* horizontal_noise) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(horizontal_noise_);
  }
  horizontal_noise_ = horizontal_noise;
  if (horizontal_noise) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.GPSSensor.Sensing.horizontal_noise)
}
inline ::gazebo::msgs::SensorNoise* GPSSensor_Sensing::release_horizontal_noise() {
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::SensorNoise* temp = horizontal_noise_;
  horizontal_noise_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::SensorNoise* GPSSensor_Sensing::unsafe_arena_release_horizontal_noise() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.GPSSensor.Sensing.horizontal_noise)
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::SensorNoise* temp = horizontal_noise_;
  horizontal_noise_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::SensorNoise* GPSSensor_Sensing::_internal_mutable_horizontal_noise() {
  _has_bits_[0] |= 0x00000001u;
  if (horizontal_noise_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::SensorNoise>(GetArenaForAllocation());
    horizontal_noise_ = p;
  }
  return horizontal_noise_;
}
inline ::gazebo::msgs::SensorNoise* GPSSensor_Sensing::mutable_horizontal_noise() {
  ::gazebo::msgs::SensorNoise* _msg = _internal_mutable_horizontal_noise();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.GPSSensor.Sensing.horizontal_noise)
  return _msg;
}
inline void GPSSensor_Sensing::set_allocated_horizontal_noise(::gazebo::msgs::SensorNoise* horizontal_noise) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(horizontal_noise_);
  }
  if (horizontal_noise) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(horizontal_noise));
    if (message_arena != submessage_arena) {
      horizontal_noise = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, horizontal_noise, submessage_arena);
    }
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  horizontal_noise_ = horizontal_noise;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.GPSSensor.Sensing.horizontal_noise)
}

// optional .gazebo.msgs.SensorNoise vertical_noise = 2;
inline bool GPSSensor_Sensing::_internal_has_vertical_noise() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || vertical_noise_ != nullptr);
  return value;
}
inline bool GPSSensor_Sensing::has_vertical_noise() const {
  return _internal_has_vertical_noise();
}
inline const ::gazebo::msgs::SensorNoise& GPSSensor_Sensing::_internal_vertical_noise() const {
  const ::gazebo::msgs::SensorNoise* p = vertical_noise_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::SensorNoise&>(
      ::gazebo::msgs::_SensorNoise_default_instance_);
}
inline const ::gazebo::msgs::SensorNoise& GPSSensor_Sensing::vertical_noise() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPSSensor.Sensing.vertical_noise)
  return _internal_vertical_noise();
}
inline void GPSSensor_Sensing::unsafe_arena_set_allocated_vertical_noise(
    ::gazebo::msgs::SensorNoise* vertical_noise) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(vertical_noise_);
  }
  vertical_noise_ = vertical_noise;
  if (vertical_noise) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.GPSSensor.Sensing.vertical_noise)
}
inline ::gazebo::msgs::SensorNoise* GPSSensor_Sensing::release_vertical_noise() {
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::SensorNoise* temp = vertical_noise_;
  vertical_noise_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::SensorNoise* GPSSensor_Sensing::unsafe_arena_release_vertical_noise() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.GPSSensor.Sensing.vertical_noise)
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::SensorNoise* temp = vertical_noise_;
  vertical_noise_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::SensorNoise* GPSSensor_Sensing::_internal_mutable_vertical_noise() {
  _has_bits_[0] |= 0x00000002u;
  if (vertical_noise_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::SensorNoise>(GetArenaForAllocation());
    vertical_noise_ = p;
  }
  return vertical_noise_;
}
inline ::gazebo::msgs::SensorNoise* GPSSensor_Sensing::mutable_vertical_noise() {
  ::gazebo::msgs::SensorNoise* _msg = _internal_mutable_vertical_noise();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.GPSSensor.Sensing.vertical_noise)
  return _msg;
}
inline void GPSSensor_Sensing::set_allocated_vertical_noise(::gazebo::msgs::SensorNoise* vertical_noise) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(vertical_noise_);
  }
  if (vertical_noise) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(vertical_noise));
    if (message_arena != submessage_arena) {
      vertical_noise = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, vertical_noise, submessage_arena);
    }
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  vertical_noise_ = vertical_noise;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.GPSSensor.Sensing.vertical_noise)
}

// -------------------------------------------------------------------

// GPSSensor

// optional .gazebo.msgs.GPSSensor.Sensing position = 1;
inline bool GPSSensor::_internal_has_position() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || position_ != nullptr);
  return value;
}
inline bool GPSSensor::has_position() const {
  return _internal_has_position();
}
inline void GPSSensor::clear_position() {
  if (position_ != nullptr) position_->Clear();
  _has_bits_[0] &= ~0x00000001u;
}
inline const ::gazebo::msgs::GPSSensor_Sensing& GPSSensor::_internal_position() const {
  const ::gazebo::msgs::GPSSensor_Sensing* p = position_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::GPSSensor_Sensing&>(
      ::gazebo::msgs::_GPSSensor_Sensing_default_instance_);
}
inline const ::gazebo::msgs::GPSSensor_Sensing& GPSSensor::position() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPSSensor.position)
  return _internal_position();
}
inline void GPSSensor::unsafe_arena_set_allocated_position(
    ::gazebo::msgs::GPSSensor_Sensing* position) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(position_);
  }
  position_ = position;
  if (position) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.GPSSensor.position)
}
inline ::gazebo::msgs::GPSSensor_Sensing* GPSSensor::release_position() {
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::GPSSensor_Sensing* temp = position_;
  position_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::GPSSensor_Sensing* GPSSensor::unsafe_arena_release_position() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.GPSSensor.position)
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::GPSSensor_Sensing* temp = position_;
  position_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::GPSSensor_Sensing* GPSSensor::_internal_mutable_position() {
  _has_bits_[0] |= 0x00000001u;
  if (position_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::GPSSensor_Sensing>(GetArenaForAllocation());
    position_ = p;
  }
  return position_;
}
inline ::gazebo::msgs::GPSSensor_Sensing* GPSSensor::mutable_position() {
  ::gazebo::msgs::GPSSensor_Sensing* _msg = _internal_mutable_position();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.GPSSensor.position)
  return _msg;
}
inline void GPSSensor::set_allocated_position(::gazebo::msgs::GPSSensor_Sensing* position) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete position_;
  }
  if (position) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::gazebo::msgs::GPSSensor_Sensing>::GetOwningArena(position);
    if (message_arena != submessage_arena) {
      position = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, position, submessage_arena);
    }
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  position_ = position;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.GPSSensor.position)
}

// optional .gazebo.msgs.GPSSensor.Sensing velocity = 2;
inline bool GPSSensor::_internal_has_velocity() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || velocity_ != nullptr);
  return value;
}
inline bool GPSSensor::has_velocity() const {
  return _internal_has_velocity();
}
inline void GPSSensor::clear_velocity() {
  if (velocity_ != nullptr) velocity_->Clear();
  _has_bits_[0] &= ~0x00000002u;
}
inline const ::gazebo::msgs::GPSSensor_Sensing& GPSSensor::_internal_velocity() const {
  const ::gazebo::msgs::GPSSensor_Sensing* p = velocity_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::GPSSensor_Sensing&>(
      ::gazebo::msgs::_GPSSensor_Sensing_default_instance_);
}
inline const ::gazebo::msgs::GPSSensor_Sensing& GPSSensor::velocity() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPSSensor.velocity)
  return _internal_velocity();
}
inline void GPSSensor::unsafe_arena_set_allocated_velocity(
    ::gazebo::msgs::GPSSensor_Sensing* velocity) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(velocity_);
  }
  velocity_ = velocity;
  if (velocity) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.GPSSensor.velocity)
}
inline ::gazebo::msgs::GPSSensor_Sensing* GPSSensor::release_velocity() {
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::GPSSensor_Sensing* temp = velocity_;
  velocity_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::GPSSensor_Sensing* GPSSensor::unsafe_arena_release_velocity() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.GPSSensor.velocity)
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::GPSSensor_Sensing* temp = velocity_;
  velocity_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::GPSSensor_Sensing* GPSSensor::_internal_mutable_velocity() {
  _has_bits_[0] |= 0x00000002u;
  if (velocity_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::GPSSensor_Sensing>(GetArenaForAllocation());
    velocity_ = p;
  }
  return velocity_;
}
inline ::gazebo::msgs::GPSSensor_Sensing* GPSSensor::mutable_velocity() {
  ::gazebo::msgs::GPSSensor_Sensing* _msg = _internal_mutable_velocity();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.GPSSensor.velocity)
  return _msg;
}
inline void GPSSensor::set_allocated_velocity(::gazebo::msgs::GPSSensor_Sensing* velocity) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete velocity_;
  }
  if (velocity) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::gazebo::msgs::GPSSensor_Sensing>::GetOwningArena(velocity);
    if (message_arena != submessage_arena) {
      velocity = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, velocity, submessage_arena);
    }
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  velocity_ = velocity;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.GPSSensor.velocity)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------


typedef boost::shared_ptr<gazebo::msgs::GPSSensor> GPSSensorPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::GPSSensor const> ConstGPSSensorPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_gps_5fsensor_2eproto
