// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: sensor.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_sensor_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_sensor_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "pose.pb.h"
#include "camerasensor.pb.h"
#include "raysensor.pb.h"
#include "contactsensor.pb.h"
#include "logical_camera_sensor.pb.h"
#include "gps_sensor.pb.h"
#include "imu_sensor.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_sensor_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_sensor_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
GZ_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_sensor_2eproto;
namespace gazebo {
namespace msgs {
class Sensor;
struct SensorDefaultTypeInternal;
GZ_MSGS_VISIBLE extern SensorDefaultTypeInternal _Sensor_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::Sensor* Arena::CreateMaybeMessage<::gazebo::msgs::Sensor>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE Sensor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.Sensor) */ {
 public:
  inline Sensor() : Sensor(nullptr) {}
  ~Sensor() override;
  explicit constexpr Sensor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Sensor(const Sensor& from);
  Sensor(Sensor&& from) noexcept
    : Sensor() {
    *this = ::std::move(from);
  }

  inline Sensor& operator=(const Sensor& from) {
    CopyFrom(from);
    return *this;
  }
  inline Sensor& operator=(Sensor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Sensor& default_instance() {
    return *internal_default_instance();
  }
  static inline const Sensor* internal_default_instance() {
    return reinterpret_cast<const Sensor*>(
               &_Sensor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Sensor& a, Sensor& b) {
    a.Swap(&b);
  }
  inline void Swap(Sensor* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Sensor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Sensor* New() const final {
    return new Sensor();
  }

  Sensor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Sensor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Sensor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Sensor& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Sensor* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.Sensor";
  }
  protected:
  explicit Sensor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kNameFieldNumber = 1,
    kParentFieldNumber = 3,
    kTypeFieldNumber = 5,
    kTopicFieldNumber = 13,
    kPoseFieldNumber = 8,
    kCameraFieldNumber = 9,
    kRayFieldNumber = 10,
    kContactFieldNumber = 11,
    kLogicalCameraFieldNumber = 14,
    kGpsFieldNumber = 15,
    kImuFieldNumber = 16,
    kIdFieldNumber = 2,
    kParentIdFieldNumber = 4,
    kUpdateRateFieldNumber = 7,
    kAlwaysOnFieldNumber = 6,
    kVisualizeFieldNumber = 12,
  };
  // required string name = 1;
  bool has_name() const;
  private:
  bool _internal_has_name() const;
  public:
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // required string parent = 3;
  bool has_parent() const;
  private:
  bool _internal_has_parent() const;
  public:
  void clear_parent();
  const std::string& parent() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_parent(ArgT0&& arg0, ArgT... args);
  std::string* mutable_parent();
  PROTOBUF_MUST_USE_RESULT std::string* release_parent();
  void set_allocated_parent(std::string* parent);
  private:
  const std::string& _internal_parent() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_parent(const std::string& value);
  std::string* _internal_mutable_parent();
  public:

  // required string type = 5;
  bool has_type() const;
  private:
  bool _internal_has_type() const;
  public:
  void clear_type();
  const std::string& type() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_type(ArgT0&& arg0, ArgT... args);
  std::string* mutable_type();
  PROTOBUF_MUST_USE_RESULT std::string* release_type();
  void set_allocated_type(std::string* type);
  private:
  const std::string& _internal_type() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_type(const std::string& value);
  std::string* _internal_mutable_type();
  public:

  // optional string topic = 13;
  bool has_topic() const;
  private:
  bool _internal_has_topic() const;
  public:
  void clear_topic();
  const std::string& topic() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_topic(ArgT0&& arg0, ArgT... args);
  std::string* mutable_topic();
  PROTOBUF_MUST_USE_RESULT std::string* release_topic();
  void set_allocated_topic(std::string* topic);
  private:
  const std::string& _internal_topic() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_topic(const std::string& value);
  std::string* _internal_mutable_topic();
  public:

  // optional .gazebo.msgs.Pose pose = 8;
  bool has_pose() const;
  private:
  bool _internal_has_pose() const;
  public:
  void clear_pose();
  const ::gazebo::msgs::Pose& pose() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::Pose* release_pose();
  ::gazebo::msgs::Pose* mutable_pose();
  void set_allocated_pose(::gazebo::msgs::Pose* pose);
  private:
  const ::gazebo::msgs::Pose& _internal_pose() const;
  ::gazebo::msgs::Pose* _internal_mutable_pose();
  public:
  void unsafe_arena_set_allocated_pose(
      ::gazebo::msgs::Pose* pose);
  ::gazebo::msgs::Pose* unsafe_arena_release_pose();

  // optional .gazebo.msgs.CameraSensor camera = 9;
  bool has_camera() const;
  private:
  bool _internal_has_camera() const;
  public:
  void clear_camera();
  const ::gazebo::msgs::CameraSensor& camera() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::CameraSensor* release_camera();
  ::gazebo::msgs::CameraSensor* mutable_camera();
  void set_allocated_camera(::gazebo::msgs::CameraSensor* camera);
  private:
  const ::gazebo::msgs::CameraSensor& _internal_camera() const;
  ::gazebo::msgs::CameraSensor* _internal_mutable_camera();
  public:
  void unsafe_arena_set_allocated_camera(
      ::gazebo::msgs::CameraSensor* camera);
  ::gazebo::msgs::CameraSensor* unsafe_arena_release_camera();

  // optional .gazebo.msgs.RaySensor ray = 10;
  bool has_ray() const;
  private:
  bool _internal_has_ray() const;
  public:
  void clear_ray();
  const ::gazebo::msgs::RaySensor& ray() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::RaySensor* release_ray();
  ::gazebo::msgs::RaySensor* mutable_ray();
  void set_allocated_ray(::gazebo::msgs::RaySensor* ray);
  private:
  const ::gazebo::msgs::RaySensor& _internal_ray() const;
  ::gazebo::msgs::RaySensor* _internal_mutable_ray();
  public:
  void unsafe_arena_set_allocated_ray(
      ::gazebo::msgs::RaySensor* ray);
  ::gazebo::msgs::RaySensor* unsafe_arena_release_ray();

  // optional .gazebo.msgs.ContactSensor contact = 11;
  bool has_contact() const;
  private:
  bool _internal_has_contact() const;
  public:
  void clear_contact();
  const ::gazebo::msgs::ContactSensor& contact() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::ContactSensor* release_contact();
  ::gazebo::msgs::ContactSensor* mutable_contact();
  void set_allocated_contact(::gazebo::msgs::ContactSensor* contact);
  private:
  const ::gazebo::msgs::ContactSensor& _internal_contact() const;
  ::gazebo::msgs::ContactSensor* _internal_mutable_contact();
  public:
  void unsafe_arena_set_allocated_contact(
      ::gazebo::msgs::ContactSensor* contact);
  ::gazebo::msgs::ContactSensor* unsafe_arena_release_contact();

  // optional .gazebo.msgs.LogicalCameraSensor logical_camera = 14;
  bool has_logical_camera() const;
  private:
  bool _internal_has_logical_camera() const;
  public:
  void clear_logical_camera();
  const ::gazebo::msgs::LogicalCameraSensor& logical_camera() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::LogicalCameraSensor* release_logical_camera();
  ::gazebo::msgs::LogicalCameraSensor* mutable_logical_camera();
  void set_allocated_logical_camera(::gazebo::msgs::LogicalCameraSensor* logical_camera);
  private:
  const ::gazebo::msgs::LogicalCameraSensor& _internal_logical_camera() const;
  ::gazebo::msgs::LogicalCameraSensor* _internal_mutable_logical_camera();
  public:
  void unsafe_arena_set_allocated_logical_camera(
      ::gazebo::msgs::LogicalCameraSensor* logical_camera);
  ::gazebo::msgs::LogicalCameraSensor* unsafe_arena_release_logical_camera();

  // optional .gazebo.msgs.GPSSensor gps = 15;
  bool has_gps() const;
  private:
  bool _internal_has_gps() const;
  public:
  void clear_gps();
  const ::gazebo::msgs::GPSSensor& gps() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::GPSSensor* release_gps();
  ::gazebo::msgs::GPSSensor* mutable_gps();
  void set_allocated_gps(::gazebo::msgs::GPSSensor* gps);
  private:
  const ::gazebo::msgs::GPSSensor& _internal_gps() const;
  ::gazebo::msgs::GPSSensor* _internal_mutable_gps();
  public:
  void unsafe_arena_set_allocated_gps(
      ::gazebo::msgs::GPSSensor* gps);
  ::gazebo::msgs::GPSSensor* unsafe_arena_release_gps();

  // optional .gazebo.msgs.IMUSensor imu = 16;
  bool has_imu() const;
  private:
  bool _internal_has_imu() const;
  public:
  void clear_imu();
  const ::gazebo::msgs::IMUSensor& imu() const;
  PROTOBUF_MUST_USE_RESULT ::gazebo::msgs::IMUSensor* release_imu();
  ::gazebo::msgs::IMUSensor* mutable_imu();
  void set_allocated_imu(::gazebo::msgs::IMUSensor* imu);
  private:
  const ::gazebo::msgs::IMUSensor& _internal_imu() const;
  ::gazebo::msgs::IMUSensor* _internal_mutable_imu();
  public:
  void unsafe_arena_set_allocated_imu(
      ::gazebo::msgs::IMUSensor* imu);
  ::gazebo::msgs::IMUSensor* unsafe_arena_release_imu();

  // optional uint32 id = 2;
  bool has_id() const;
  private:
  bool _internal_has_id() const;
  public:
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // optional uint32 parent_id = 4;
  bool has_parent_id() const;
  private:
  bool _internal_has_parent_id() const;
  public:
  void clear_parent_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 parent_id() const;
  void set_parent_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_parent_id() const;
  void _internal_set_parent_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // optional double update_rate = 7;
  bool has_update_rate() const;
  private:
  bool _internal_has_update_rate() const;
  public:
  void clear_update_rate();
  double update_rate() const;
  void set_update_rate(double value);
  private:
  double _internal_update_rate() const;
  void _internal_set_update_rate(double value);
  public:

  // optional bool always_on = 6;
  bool has_always_on() const;
  private:
  bool _internal_has_always_on() const;
  public:
  void clear_always_on();
  bool always_on() const;
  void set_always_on(bool value);
  private:
  bool _internal_always_on() const;
  void _internal_set_always_on(bool value);
  public:

  // optional bool visualize = 12;
  bool has_visualize() const;
  private:
  bool _internal_has_visualize() const;
  public:
  void clear_visualize();
  bool visualize() const;
  void set_visualize(bool value);
  private:
  bool _internal_visualize() const;
  void _internal_set_visualize(bool value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.Sensor)
 private:
  class _Internal;

  // helper for ByteSizeLong()
  size_t RequiredFieldsByteSizeFallback() const;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr parent_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr type_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr topic_;
  ::gazebo::msgs::Pose* pose_;
  ::gazebo::msgs::CameraSensor* camera_;
  ::gazebo::msgs::RaySensor* ray_;
  ::gazebo::msgs::ContactSensor* contact_;
  ::gazebo::msgs::LogicalCameraSensor* logical_camera_;
  ::gazebo::msgs::GPSSensor* gps_;
  ::gazebo::msgs::IMUSensor* imu_;
  ::PROTOBUF_NAMESPACE_ID::uint32 id_;
  ::PROTOBUF_NAMESPACE_ID::uint32 parent_id_;
  double update_rate_;
  bool always_on_;
  bool visualize_;
  friend struct ::TableStruct_sensor_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Sensor

// required string name = 1;
inline bool Sensor::_internal_has_name() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool Sensor::has_name() const {
  return _internal_has_name();
}
inline void Sensor::clear_name() {
  name_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000001u;
}
inline const std::string& Sensor::name() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Sensor::set_name(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000001u;
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.Sensor.name)
}
inline std::string* Sensor::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.name)
  return _s;
}
inline const std::string& Sensor::_internal_name() const {
  return name_.Get();
}
inline void Sensor::_internal_set_name(const std::string& value) {
  _has_bits_[0] |= 0x00000001u;
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Sensor::_internal_mutable_name() {
  _has_bits_[0] |= 0x00000001u;
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Sensor::release_name() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.name)
  if (!_internal_has_name()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000001u;
  return name_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Sensor::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.name)
}

// optional uint32 id = 2;
inline bool Sensor::_internal_has_id() const {
  bool value = (_has_bits_[0] & 0x00000800u) != 0;
  return value;
}
inline bool Sensor::has_id() const {
  return _internal_has_id();
}
inline void Sensor::clear_id() {
  id_ = 0u;
  _has_bits_[0] &= ~0x00000800u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Sensor::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Sensor::id() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.id)
  return _internal_id();
}
inline void Sensor::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _has_bits_[0] |= 0x00000800u;
  id_ = value;
}
inline void Sensor::set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Sensor.id)
}

// required string parent = 3;
inline bool Sensor::_internal_has_parent() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool Sensor::has_parent() const {
  return _internal_has_parent();
}
inline void Sensor::clear_parent() {
  parent_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000002u;
}
inline const std::string& Sensor::parent() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.parent)
  return _internal_parent();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Sensor::set_parent(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000002u;
 parent_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.Sensor.parent)
}
inline std::string* Sensor::mutable_parent() {
  std::string* _s = _internal_mutable_parent();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.parent)
  return _s;
}
inline const std::string& Sensor::_internal_parent() const {
  return parent_.Get();
}
inline void Sensor::_internal_set_parent(const std::string& value) {
  _has_bits_[0] |= 0x00000002u;
  parent_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Sensor::_internal_mutable_parent() {
  _has_bits_[0] |= 0x00000002u;
  return parent_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Sensor::release_parent() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.parent)
  if (!_internal_has_parent()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000002u;
  return parent_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Sensor::set_allocated_parent(std::string* parent) {
  if (parent != nullptr) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  parent_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), parent,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.parent)
}

// optional uint32 parent_id = 4;
inline bool Sensor::_internal_has_parent_id() const {
  bool value = (_has_bits_[0] & 0x00001000u) != 0;
  return value;
}
inline bool Sensor::has_parent_id() const {
  return _internal_has_parent_id();
}
inline void Sensor::clear_parent_id() {
  parent_id_ = 0u;
  _has_bits_[0] &= ~0x00001000u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Sensor::_internal_parent_id() const {
  return parent_id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Sensor::parent_id() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.parent_id)
  return _internal_parent_id();
}
inline void Sensor::_internal_set_parent_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _has_bits_[0] |= 0x00001000u;
  parent_id_ = value;
}
inline void Sensor::set_parent_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_parent_id(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Sensor.parent_id)
}

// required string type = 5;
inline bool Sensor::_internal_has_type() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool Sensor::has_type() const {
  return _internal_has_type();
}
inline void Sensor::clear_type() {
  type_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000004u;
}
inline const std::string& Sensor::type() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.type)
  return _internal_type();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Sensor::set_type(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000004u;
 type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.Sensor.type)
}
inline std::string* Sensor::mutable_type() {
  std::string* _s = _internal_mutable_type();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.type)
  return _s;
}
inline const std::string& Sensor::_internal_type() const {
  return type_.Get();
}
inline void Sensor::_internal_set_type(const std::string& value) {
  _has_bits_[0] |= 0x00000004u;
  type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Sensor::_internal_mutable_type() {
  _has_bits_[0] |= 0x00000004u;
  return type_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Sensor::release_type() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.type)
  if (!_internal_has_type()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000004u;
  return type_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Sensor::set_allocated_type(std::string* type) {
  if (type != nullptr) {
    _has_bits_[0] |= 0x00000004u;
  } else {
    _has_bits_[0] &= ~0x00000004u;
  }
  type_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), type,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.type)
}

// optional bool always_on = 6;
inline bool Sensor::_internal_has_always_on() const {
  bool value = (_has_bits_[0] & 0x00004000u) != 0;
  return value;
}
inline bool Sensor::has_always_on() const {
  return _internal_has_always_on();
}
inline void Sensor::clear_always_on() {
  always_on_ = false;
  _has_bits_[0] &= ~0x00004000u;
}
inline bool Sensor::_internal_always_on() const {
  return always_on_;
}
inline bool Sensor::always_on() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.always_on)
  return _internal_always_on();
}
inline void Sensor::_internal_set_always_on(bool value) {
  _has_bits_[0] |= 0x00004000u;
  always_on_ = value;
}
inline void Sensor::set_always_on(bool value) {
  _internal_set_always_on(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Sensor.always_on)
}

// optional double update_rate = 7;
inline bool Sensor::_internal_has_update_rate() const {
  bool value = (_has_bits_[0] & 0x00002000u) != 0;
  return value;
}
inline bool Sensor::has_update_rate() const {
  return _internal_has_update_rate();
}
inline void Sensor::clear_update_rate() {
  update_rate_ = 0;
  _has_bits_[0] &= ~0x00002000u;
}
inline double Sensor::_internal_update_rate() const {
  return update_rate_;
}
inline double Sensor::update_rate() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.update_rate)
  return _internal_update_rate();
}
inline void Sensor::_internal_set_update_rate(double value) {
  _has_bits_[0] |= 0x00002000u;
  update_rate_ = value;
}
inline void Sensor::set_update_rate(double value) {
  _internal_set_update_rate(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Sensor.update_rate)
}

// optional .gazebo.msgs.Pose pose = 8;
inline bool Sensor::_internal_has_pose() const {
  bool value = (_has_bits_[0] & 0x00000010u) != 0;
  PROTOBUF_ASSUME(!value || pose_ != nullptr);
  return value;
}
inline bool Sensor::has_pose() const {
  return _internal_has_pose();
}
inline const ::gazebo::msgs::Pose& Sensor::_internal_pose() const {
  const ::gazebo::msgs::Pose* p = pose_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::Pose&>(
      ::gazebo::msgs::_Pose_default_instance_);
}
inline const ::gazebo::msgs::Pose& Sensor::pose() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.pose)
  return _internal_pose();
}
inline void Sensor::unsafe_arena_set_allocated_pose(
    ::gazebo::msgs::Pose* pose) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  pose_ = pose;
  if (pose) {
    _has_bits_[0] |= 0x00000010u;
  } else {
    _has_bits_[0] &= ~0x00000010u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Sensor.pose)
}
inline ::gazebo::msgs::Pose* Sensor::release_pose() {
  _has_bits_[0] &= ~0x00000010u;
  ::gazebo::msgs::Pose* temp = pose_;
  pose_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::Pose* Sensor::unsafe_arena_release_pose() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.pose)
  _has_bits_[0] &= ~0x00000010u;
  ::gazebo::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::Pose* Sensor::_internal_mutable_pose() {
  _has_bits_[0] |= 0x00000010u;
  if (pose_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::Pose>(GetArenaForAllocation());
    pose_ = p;
  }
  return pose_;
}
inline ::gazebo::msgs::Pose* Sensor::mutable_pose() {
  ::gazebo::msgs::Pose* _msg = _internal_mutable_pose();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.pose)
  return _msg;
}
inline void Sensor::set_allocated_pose(::gazebo::msgs::Pose* pose) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  if (pose) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose));
    if (message_arena != submessage_arena) {
      pose = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pose, submessage_arena);
    }
    _has_bits_[0] |= 0x00000010u;
  } else {
    _has_bits_[0] &= ~0x00000010u;
  }
  pose_ = pose;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.pose)
}

// optional .gazebo.msgs.CameraSensor camera = 9;
inline bool Sensor::_internal_has_camera() const {
  bool value = (_has_bits_[0] & 0x00000020u) != 0;
  PROTOBUF_ASSUME(!value || camera_ != nullptr);
  return value;
}
inline bool Sensor::has_camera() const {
  return _internal_has_camera();
}
inline const ::gazebo::msgs::CameraSensor& Sensor::_internal_camera() const {
  const ::gazebo::msgs::CameraSensor* p = camera_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::CameraSensor&>(
      ::gazebo::msgs::_CameraSensor_default_instance_);
}
inline const ::gazebo::msgs::CameraSensor& Sensor::camera() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.camera)
  return _internal_camera();
}
inline void Sensor::unsafe_arena_set_allocated_camera(
    ::gazebo::msgs::CameraSensor* camera) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(camera_);
  }
  camera_ = camera;
  if (camera) {
    _has_bits_[0] |= 0x00000020u;
  } else {
    _has_bits_[0] &= ~0x00000020u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Sensor.camera)
}
inline ::gazebo::msgs::CameraSensor* Sensor::release_camera() {
  _has_bits_[0] &= ~0x00000020u;
  ::gazebo::msgs::CameraSensor* temp = camera_;
  camera_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::CameraSensor* Sensor::unsafe_arena_release_camera() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.camera)
  _has_bits_[0] &= ~0x00000020u;
  ::gazebo::msgs::CameraSensor* temp = camera_;
  camera_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::CameraSensor* Sensor::_internal_mutable_camera() {
  _has_bits_[0] |= 0x00000020u;
  if (camera_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::CameraSensor>(GetArenaForAllocation());
    camera_ = p;
  }
  return camera_;
}
inline ::gazebo::msgs::CameraSensor* Sensor::mutable_camera() {
  ::gazebo::msgs::CameraSensor* _msg = _internal_mutable_camera();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.camera)
  return _msg;
}
inline void Sensor::set_allocated_camera(::gazebo::msgs::CameraSensor* camera) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(camera_);
  }
  if (camera) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(camera));
    if (message_arena != submessage_arena) {
      camera = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, camera, submessage_arena);
    }
    _has_bits_[0] |= 0x00000020u;
  } else {
    _has_bits_[0] &= ~0x00000020u;
  }
  camera_ = camera;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.camera)
}

// optional .gazebo.msgs.RaySensor ray = 10;
inline bool Sensor::_internal_has_ray() const {
  bool value = (_has_bits_[0] & 0x00000040u) != 0;
  PROTOBUF_ASSUME(!value || ray_ != nullptr);
  return value;
}
inline bool Sensor::has_ray() const {
  return _internal_has_ray();
}
inline const ::gazebo::msgs::RaySensor& Sensor::_internal_ray() const {
  const ::gazebo::msgs::RaySensor* p = ray_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::RaySensor&>(
      ::gazebo::msgs::_RaySensor_default_instance_);
}
inline const ::gazebo::msgs::RaySensor& Sensor::ray() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.ray)
  return _internal_ray();
}
inline void Sensor::unsafe_arena_set_allocated_ray(
    ::gazebo::msgs::RaySensor* ray) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(ray_);
  }
  ray_ = ray;
  if (ray) {
    _has_bits_[0] |= 0x00000040u;
  } else {
    _has_bits_[0] &= ~0x00000040u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Sensor.ray)
}
inline ::gazebo::msgs::RaySensor* Sensor::release_ray() {
  _has_bits_[0] &= ~0x00000040u;
  ::gazebo::msgs::RaySensor* temp = ray_;
  ray_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::RaySensor* Sensor::unsafe_arena_release_ray() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.ray)
  _has_bits_[0] &= ~0x00000040u;
  ::gazebo::msgs::RaySensor* temp = ray_;
  ray_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::RaySensor* Sensor::_internal_mutable_ray() {
  _has_bits_[0] |= 0x00000040u;
  if (ray_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::RaySensor>(GetArenaForAllocation());
    ray_ = p;
  }
  return ray_;
}
inline ::gazebo::msgs::RaySensor* Sensor::mutable_ray() {
  ::gazebo::msgs::RaySensor* _msg = _internal_mutable_ray();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.ray)
  return _msg;
}
inline void Sensor::set_allocated_ray(::gazebo::msgs::RaySensor* ray) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(ray_);
  }
  if (ray) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(ray));
    if (message_arena != submessage_arena) {
      ray = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, ray, submessage_arena);
    }
    _has_bits_[0] |= 0x00000040u;
  } else {
    _has_bits_[0] &= ~0x00000040u;
  }
  ray_ = ray;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.ray)
}

// optional .gazebo.msgs.ContactSensor contact = 11;
inline bool Sensor::_internal_has_contact() const {
  bool value = (_has_bits_[0] & 0x00000080u) != 0;
  PROTOBUF_ASSUME(!value || contact_ != nullptr);
  return value;
}
inline bool Sensor::has_contact() const {
  return _internal_has_contact();
}
inline const ::gazebo::msgs::ContactSensor& Sensor::_internal_contact() const {
  const ::gazebo::msgs::ContactSensor* p = contact_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::ContactSensor&>(
      ::gazebo::msgs::_ContactSensor_default_instance_);
}
inline const ::gazebo::msgs::ContactSensor& Sensor::contact() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.contact)
  return _internal_contact();
}
inline void Sensor::unsafe_arena_set_allocated_contact(
    ::gazebo::msgs::ContactSensor* contact) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(contact_);
  }
  contact_ = contact;
  if (contact) {
    _has_bits_[0] |= 0x00000080u;
  } else {
    _has_bits_[0] &= ~0x00000080u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Sensor.contact)
}
inline ::gazebo::msgs::ContactSensor* Sensor::release_contact() {
  _has_bits_[0] &= ~0x00000080u;
  ::gazebo::msgs::ContactSensor* temp = contact_;
  contact_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::ContactSensor* Sensor::unsafe_arena_release_contact() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.contact)
  _has_bits_[0] &= ~0x00000080u;
  ::gazebo::msgs::ContactSensor* temp = contact_;
  contact_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::ContactSensor* Sensor::_internal_mutable_contact() {
  _has_bits_[0] |= 0x00000080u;
  if (contact_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::ContactSensor>(GetArenaForAllocation());
    contact_ = p;
  }
  return contact_;
}
inline ::gazebo::msgs::ContactSensor* Sensor::mutable_contact() {
  ::gazebo::msgs::ContactSensor* _msg = _internal_mutable_contact();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.contact)
  return _msg;
}
inline void Sensor::set_allocated_contact(::gazebo::msgs::ContactSensor* contact) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(contact_);
  }
  if (contact) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(contact));
    if (message_arena != submessage_arena) {
      contact = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, contact, submessage_arena);
    }
    _has_bits_[0] |= 0x00000080u;
  } else {
    _has_bits_[0] &= ~0x00000080u;
  }
  contact_ = contact;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.contact)
}

// optional bool visualize = 12;
inline bool Sensor::_internal_has_visualize() const {
  bool value = (_has_bits_[0] & 0x00008000u) != 0;
  return value;
}
inline bool Sensor::has_visualize() const {
  return _internal_has_visualize();
}
inline void Sensor::clear_visualize() {
  visualize_ = false;
  _has_bits_[0] &= ~0x00008000u;
}
inline bool Sensor::_internal_visualize() const {
  return visualize_;
}
inline bool Sensor::visualize() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.visualize)
  return _internal_visualize();
}
inline void Sensor::_internal_set_visualize(bool value) {
  _has_bits_[0] |= 0x00008000u;
  visualize_ = value;
}
inline void Sensor::set_visualize(bool value) {
  _internal_set_visualize(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Sensor.visualize)
}

// optional string topic = 13;
inline bool Sensor::_internal_has_topic() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool Sensor::has_topic() const {
  return _internal_has_topic();
}
inline void Sensor::clear_topic() {
  topic_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000008u;
}
inline const std::string& Sensor::topic() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.topic)
  return _internal_topic();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Sensor::set_topic(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000008u;
 topic_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.Sensor.topic)
}
inline std::string* Sensor::mutable_topic() {
  std::string* _s = _internal_mutable_topic();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.topic)
  return _s;
}
inline const std::string& Sensor::_internal_topic() const {
  return topic_.Get();
}
inline void Sensor::_internal_set_topic(const std::string& value) {
  _has_bits_[0] |= 0x00000008u;
  topic_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Sensor::_internal_mutable_topic() {
  _has_bits_[0] |= 0x00000008u;
  return topic_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Sensor::release_topic() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.topic)
  if (!_internal_has_topic()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000008u;
  return topic_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Sensor::set_allocated_topic(std::string* topic) {
  if (topic != nullptr) {
    _has_bits_[0] |= 0x00000008u;
  } else {
    _has_bits_[0] &= ~0x00000008u;
  }
  topic_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), topic,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.topic)
}

// optional .gazebo.msgs.LogicalCameraSensor logical_camera = 14;
inline bool Sensor::_internal_has_logical_camera() const {
  bool value = (_has_bits_[0] & 0x00000100u) != 0;
  PROTOBUF_ASSUME(!value || logical_camera_ != nullptr);
  return value;
}
inline bool Sensor::has_logical_camera() const {
  return _internal_has_logical_camera();
}
inline const ::gazebo::msgs::LogicalCameraSensor& Sensor::_internal_logical_camera() const {
  const ::gazebo::msgs::LogicalCameraSensor* p = logical_camera_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::LogicalCameraSensor&>(
      ::gazebo::msgs::_LogicalCameraSensor_default_instance_);
}
inline const ::gazebo::msgs::LogicalCameraSensor& Sensor::logical_camera() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.logical_camera)
  return _internal_logical_camera();
}
inline void Sensor::unsafe_arena_set_allocated_logical_camera(
    ::gazebo::msgs::LogicalCameraSensor* logical_camera) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(logical_camera_);
  }
  logical_camera_ = logical_camera;
  if (logical_camera) {
    _has_bits_[0] |= 0x00000100u;
  } else {
    _has_bits_[0] &= ~0x00000100u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Sensor.logical_camera)
}
inline ::gazebo::msgs::LogicalCameraSensor* Sensor::release_logical_camera() {
  _has_bits_[0] &= ~0x00000100u;
  ::gazebo::msgs::LogicalCameraSensor* temp = logical_camera_;
  logical_camera_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::LogicalCameraSensor* Sensor::unsafe_arena_release_logical_camera() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.logical_camera)
  _has_bits_[0] &= ~0x00000100u;
  ::gazebo::msgs::LogicalCameraSensor* temp = logical_camera_;
  logical_camera_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::LogicalCameraSensor* Sensor::_internal_mutable_logical_camera() {
  _has_bits_[0] |= 0x00000100u;
  if (logical_camera_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::LogicalCameraSensor>(GetArenaForAllocation());
    logical_camera_ = p;
  }
  return logical_camera_;
}
inline ::gazebo::msgs::LogicalCameraSensor* Sensor::mutable_logical_camera() {
  ::gazebo::msgs::LogicalCameraSensor* _msg = _internal_mutable_logical_camera();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.logical_camera)
  return _msg;
}
inline void Sensor::set_allocated_logical_camera(::gazebo::msgs::LogicalCameraSensor* logical_camera) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(logical_camera_);
  }
  if (logical_camera) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(logical_camera));
    if (message_arena != submessage_arena) {
      logical_camera = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, logical_camera, submessage_arena);
    }
    _has_bits_[0] |= 0x00000100u;
  } else {
    _has_bits_[0] &= ~0x00000100u;
  }
  logical_camera_ = logical_camera;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.logical_camera)
}

// optional .gazebo.msgs.GPSSensor gps = 15;
inline bool Sensor::_internal_has_gps() const {
  bool value = (_has_bits_[0] & 0x00000200u) != 0;
  PROTOBUF_ASSUME(!value || gps_ != nullptr);
  return value;
}
inline bool Sensor::has_gps() const {
  return _internal_has_gps();
}
inline const ::gazebo::msgs::GPSSensor& Sensor::_internal_gps() const {
  const ::gazebo::msgs::GPSSensor* p = gps_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::GPSSensor&>(
      ::gazebo::msgs::_GPSSensor_default_instance_);
}
inline const ::gazebo::msgs::GPSSensor& Sensor::gps() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.gps)
  return _internal_gps();
}
inline void Sensor::unsafe_arena_set_allocated_gps(
    ::gazebo::msgs::GPSSensor* gps) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(gps_);
  }
  gps_ = gps;
  if (gps) {
    _has_bits_[0] |= 0x00000200u;
  } else {
    _has_bits_[0] &= ~0x00000200u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Sensor.gps)
}
inline ::gazebo::msgs::GPSSensor* Sensor::release_gps() {
  _has_bits_[0] &= ~0x00000200u;
  ::gazebo::msgs::GPSSensor* temp = gps_;
  gps_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::GPSSensor* Sensor::unsafe_arena_release_gps() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.gps)
  _has_bits_[0] &= ~0x00000200u;
  ::gazebo::msgs::GPSSensor* temp = gps_;
  gps_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::GPSSensor* Sensor::_internal_mutable_gps() {
  _has_bits_[0] |= 0x00000200u;
  if (gps_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::GPSSensor>(GetArenaForAllocation());
    gps_ = p;
  }
  return gps_;
}
inline ::gazebo::msgs::GPSSensor* Sensor::mutable_gps() {
  ::gazebo::msgs::GPSSensor* _msg = _internal_mutable_gps();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.gps)
  return _msg;
}
inline void Sensor::set_allocated_gps(::gazebo::msgs::GPSSensor* gps) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(gps_);
  }
  if (gps) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(gps));
    if (message_arena != submessage_arena) {
      gps = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, gps, submessage_arena);
    }
    _has_bits_[0] |= 0x00000200u;
  } else {
    _has_bits_[0] &= ~0x00000200u;
  }
  gps_ = gps;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.gps)
}

// optional .gazebo.msgs.IMUSensor imu = 16;
inline bool Sensor::_internal_has_imu() const {
  bool value = (_has_bits_[0] & 0x00000400u) != 0;
  PROTOBUF_ASSUME(!value || imu_ != nullptr);
  return value;
}
inline bool Sensor::has_imu() const {
  return _internal_has_imu();
}
inline const ::gazebo::msgs::IMUSensor& Sensor::_internal_imu() const {
  const ::gazebo::msgs::IMUSensor* p = imu_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::IMUSensor&>(
      ::gazebo::msgs::_IMUSensor_default_instance_);
}
inline const ::gazebo::msgs::IMUSensor& Sensor::imu() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Sensor.imu)
  return _internal_imu();
}
inline void Sensor::unsafe_arena_set_allocated_imu(
    ::gazebo::msgs::IMUSensor* imu) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(imu_);
  }
  imu_ = imu;
  if (imu) {
    _has_bits_[0] |= 0x00000400u;
  } else {
    _has_bits_[0] &= ~0x00000400u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Sensor.imu)
}
inline ::gazebo::msgs::IMUSensor* Sensor::release_imu() {
  _has_bits_[0] &= ~0x00000400u;
  ::gazebo::msgs::IMUSensor* temp = imu_;
  imu_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::IMUSensor* Sensor::unsafe_arena_release_imu() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Sensor.imu)
  _has_bits_[0] &= ~0x00000400u;
  ::gazebo::msgs::IMUSensor* temp = imu_;
  imu_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::IMUSensor* Sensor::_internal_mutable_imu() {
  _has_bits_[0] |= 0x00000400u;
  if (imu_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::IMUSensor>(GetArenaForAllocation());
    imu_ = p;
  }
  return imu_;
}
inline ::gazebo::msgs::IMUSensor* Sensor::mutable_imu() {
  ::gazebo::msgs::IMUSensor* _msg = _internal_mutable_imu();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Sensor.imu)
  return _msg;
}
inline void Sensor::set_allocated_imu(::gazebo::msgs::IMUSensor* imu) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(imu_);
  }
  if (imu) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(imu));
    if (message_arena != submessage_arena) {
      imu = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, imu, submessage_arena);
    }
    _has_bits_[0] |= 0x00000400u;
  } else {
    _has_bits_[0] &= ~0x00000400u;
  }
  imu_ = imu;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Sensor.imu)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::Sensor> SensorPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::Sensor const> ConstSensorPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_sensor_2eproto
