syntax = "proto2";
package gazebo.msgs;

/// \ingroup gazebo_msgs
/// \interface MeshGeom 
/// \brief Message for a mesh geometry


import "vector3d.proto";

message MeshGeom
{
  required string filename = 1;
  optional Vector3d scale  = 2;
  optional string submesh  = 3;
  optional bool center_submesh = 4;
}
